#
# Conditional build:
%bcond_without	static_libs	# don't build static libraries
%bcond_without	tests		# don't perform "make check"
#
Summary:	Library of Optimized Inner Loops
Summary(pl.UTF-8):	Biblioteka zoptymalizowanych wewnętrznych pętli
Name:		liboil
Version:	0.3.17
Release:	2
Epoch:		1
License:	BSD
Group:		Libraries
Source0:	http://liboil.freedesktop.org/download/%{name}-%{version}.tar.gz
# Source0-md5:	47dc734f82faeb2964d97771cfd2e701
Patch0:		%{name}-opt.patch
Patch1:		%{name}-fixes.patch
Patch2:		x32.patch
URL:		http://liboil.freedesktop.org/wiki/
BuildRequires:	autoconf >= 2.58
BuildRequires:	automake >= 1.6
BuildRequires:	glib2-devel >= 2.0
BuildRequires:	gtk-doc-automake >= 1.0
BuildRequires:	libltdl-devel
BuildRequires:	libtool
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.98
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

# NOTE: cannot remove frame pointers on x86, SSE wrapper hack relies on gcc stack frames

# won't compile without altivec (CFLAGS_ALTIVEC are set, but not used)
%define		specflags_ppc	-maltivec

%description
Liboil is a library of simple functions that are optimized for various
CPUs. These functions are generally loops implementing simple
algorithms, such as converting an array of N integers to
floating-poing numbers or multiplying and summing an array of N
numbers. Clearly such functions are candidates for significant
optimization using various techniques, especially by using extended
instructions provided by modern CPUs (Altivec, MMX, SSE, etc.).

Many multimedia applications and libraries already do similar things
internally. The goal of this project is to consolidate some of the
code used by various multimedia projects, and also make optimizations
easier to use by a broad range of applications.

%description -l pl.UTF-8
Liboil to biblioteka prostych funkcji zoptymalizowanych dla różnych
procesorów. Funkcje te to zwykle pętle implementujące proste
algorytmy, takie jak konwersja tablicy N liczb całkowitych na liczby
zmiennoprzecinkowe albo mnożenie i dodawanie tablicy N liczb. Takie
funkcje są kandydatami do znaczącej optymalizacji przy użyciu różnych
technik, szczególnie poprzez użycie rozszerzonych instrukcji
udostępnianych przez nowoczesne procesory (Altivec, MMX, SSE itp.).

Wiele aplikacji multimedialnych i bibliotek już robi takie rzeczy
wewnętrznie. Celem tego projektu jest połączenie części kodu używanego
przez różne projekty multimedialne i ułatwienie używania optymalizacji
w szerszym zakresie aplikacji.

%package devel
Summary:	Header files for liboil library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki liboil
Group:		Development/Libraries
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description devel
Header files for liboil library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki liboil.

%package static
Summary:	Static liboil library
Summary(pl.UTF-8):	Statyczna biblioteka liboil
Group:		Development/Libraries
Requires:	%{name}-devel = %{epoch}:%{version}-%{release}

%description static
Static liboil library.

%description static -l pl.UTF-8
Statyczna biblioteka liboil.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%ifarch x32
%patch2 -p1
%endif

rm -f m4/libtool.m4 m4/lt*.m4

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}

%configure \
	--with-html-dir=%{_gtkdocdir} \
	%{!?with_static_libs:--disable-static}

%{__make}

%{?with_tests:%{__make} check}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%{__make} clean -C examples
cp -rf examples/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

rm -f $RPM_BUILD_ROOT%{_libdir}/liboiltmp1*

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README
%attr(755,root,root) %{_libdir}/liboil-0.3.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/liboil-0.3.so.0

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/liboil-0.3.so
%{_libdir}/liboil-0.3.la
%{_includedir}/liboil-0.3
%{_pkgconfigdir}/liboil-0.3.pc
%{_gtkdocdir}/liboil
%{_examplesdir}/%{name}-%{version}

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/liboil-0.3.a
%endif
%changelog
* Sat May 09 2015 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/liboil.git;a=log;h=master

* Sat May 09 2015 Jan Rękorajski <baggins@pld-linux.org> d1b153a
- disable some asm on x32
- rel 2

* Wed Aug 25 2010 Jakub Bogusz <qboosh@pld-linux.org> 613aa2f
- updated to 0.3.17

* Tue Aug 24 2010 Elan Ruusamäe <glen@pld-linux.org> 726c0ca
- release 3

* Tue Aug 24 2010 Elan Ruusamäe <glen@pld-linux.org> 6563de2
- remove libtool m4 copies

* Mon Nov 30 2009 sparky <sparky@pld-linux.org> d9e8f6c
- BR: libltdl-devel

* Sun Jul 05 2009 Arkadiusz Miśkiewicz <arekm@maven.pl> b800f20
- drop obsolete files

* Tue May 05 2009 sparky <sparky@pld-linux.org> f437fd7
- rel 2 (fixed on ppc)

* Sun May 03 2009 sparky <sparky@pld-linux.org> ceec82d
- drop -j1

* Sun May 03 2009 sparky <sparky@pld-linux.org> 0f83728
- removed no_altivec.patch, outdated long time ago

* Sun May 03 2009 sparky <sparky@pld-linux.org> 651f58e
- so much unaligned write access doesn't seem like a good idea

* Sun May 03 2009 sparky <sparky@pld-linux.org> 39b4050
- added fixes patch [ this lib is rubbish ! hear me ?! rubbish !!! ]

* Sun May 03 2009 sparky <sparky@pld-linux.org> 8e95404
- clobber register used in asm

* Mon Mar 30 2009 Jakub Bogusz <qboosh@pld-linux.org> 131d05a
- updated to 0.3.16

* Thu Aug 21 2008 Jakub Bogusz <qboosh@pld-linux.org> 6e15d4b
- updated to 0.3.15

* Thu Jun 19 2008 Patryk Zawadzki <patrys@room-303.com> 860d7f7
- rel 2

* Sun Apr 13 2008 Jakub Bogusz <qboosh@pld-linux.org> 85d600d
- updated to 0.3.14

* Sun Nov 04 2007 Jakub Bogusz <qboosh@pld-linux.org> 0579cb4
- cannot -fomit-frame-pointer on x86 due to SSE hacks

* Mon Aug 20 2007 witekfl <witekfl@pld-linux.org> 3c1091a
- added bcond_without static_libs

* Tue Jun 12 2007 Arkadiusz Miśkiewicz <arekm@maven.pl> 0b36422
- up to 0.3.12

* Sun Apr 15 2007 Arkadiusz Miśkiewicz <arekm@maven.pl> 2439615
- rel 2

